@@ -19,7 +19,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 
 */
 // Self
-#include "zoomwidget.moc"
+#include "zoomwidget.h"
 
 // stdc++
 #include <cmath>
@@ -32,8 +32,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 #include <QSlider>
 
 // KDE
-#include <KDebug>
-#include <KIcon>
 
 // Local
 #include "zoomslider.h"
@@ -62,12 +60,12 @@ struct ZoomWidgetPrivate
 
     StatusBarToolButton* mZoomToFitButton;
     StatusBarToolButton* mActualSizeButton;
+    StatusBarToolButton* mZoomToFitWidthButton;
     QLabel* mZoomLabel;
     ZoomSlider* mZoomSlider;
     QAction* mZoomToFitAction;
     QAction* mActualSizeAction;
-
-    QToolButton* mLockZoomButton;
+    QAction* mZoomToFitWidthAction;
 
     bool mZoomUpdatedBySlider;
 
@@ -94,12 +92,19 @@ ZoomWidget::ZoomWidget(QWidget* parent)
 
     d->mZoomToFitButton = new StatusBarToolButton;
     d->mActualSizeButton = new StatusBarToolButton;
+    d->mZoomToFitWidthButton = new StatusBarToolButton;
+    d->mZoomToFitButton->setCheckable(true);
+    d->mActualSizeButton->setCheckable(true);
+    d->mZoomToFitWidthButton->setCheckable(true);
+    d->mZoomToFitButton->setChecked(true);
 
     if (QApplication::isLeftToRight()) {
         d->mZoomToFitButton->setGroupPosition(StatusBarToolButton::GroupLeft);
+        d->mZoomToFitWidthButton->setGroupPosition(StatusBarToolButton::GroupCenter);
         d->mActualSizeButton->setGroupPosition(StatusBarToolButton::GroupRight);
     } else {
         d->mActualSizeButton->setGroupPosition(StatusBarToolButton::GroupLeft);
+        d->mZoomToFitWidthButton->setGroupPosition(StatusBarToolButton::GroupCenter);
         d->mZoomToFitButton->setGroupPosition(StatusBarToolButton::GroupRight);
     }
 
@@ -113,21 +118,15 @@ ZoomWidget::ZoomWidget(QWidget* parent)
     d->mZoomSlider->slider()->setPageStep(3 * int(PRECISION));
     connect(d->mZoomSlider->slider(), SIGNAL(actionTriggered(int)), SLOT(slotZoomSliderActionTriggered()));
 
-    d->mLockZoomButton = new QToolButton;
-    d->mLockZoomButton->setAutoRaise(true);
-    d->mLockZoomButton->setCheckable(true);
-    updateLockZoomButton();
-    connect(d->mLockZoomButton, SIGNAL(toggled(bool)), SLOT(updateLockZoomButton()));
-
     // Layout
     QHBoxLayout* layout = new QHBoxLayout(this);
     layout->setMargin(0);
     layout->setSpacing(0);
     layout->addWidget(d->mZoomToFitButton);
+    layout->addWidget(d->mZoomToFitWidthButton);
     layout->addWidget(d->mActualSizeButton);
     layout->addWidget(d->mZoomSlider);
     layout->addWidget(d->mZoomLabel);
-    layout->addWidget(d->mLockZoomButton);
 }
 
 ZoomWidget::~ZoomWidget()
@@ -135,21 +134,30 @@ ZoomWidget::~ZoomWidget()
     delete d;
 }
 
-void ZoomWidget::setActions(QAction* zoomToFitAction, QAction* actualSizeAction, QAction* zoomInAction, QAction* zoomOutAction)
+void ZoomWidget::setActions(QAction* zoomToFitAction, QAction* actualSizeAction, QAction* zoomInAction, QAction* zoomOutAction, QAction* zoomToFitWidthAction)
 {
     d->mZoomToFitAction = zoomToFitAction;
     d->mActualSizeAction = actualSizeAction;
+    d->mZoomToFitWidthAction = zoomToFitWidthAction;
 
     d->mZoomToFitButton->setDefaultAction(zoomToFitAction);
     d->mActualSizeButton->setDefaultAction(actualSizeAction);
+    d->mZoomToFitWidthButton->setDefaultAction(zoomToFitWidthAction);
 
     d->mZoomSlider->setZoomInAction(zoomInAction);
     d->mZoomSlider->setZoomOutAction(zoomOutAction);
 
+    QActionGroup *actionGroup = new QActionGroup(d->q);
+    actionGroup->addAction(d->mZoomToFitAction);
+    actionGroup->addAction(d->mZoomToFitWidthAction);
+    actionGroup->addAction(d->mActualSizeAction);
+    actionGroup->setExclusive(true);
+
     // Adjust sizes
     int width = qMax(d->mZoomToFitButton->sizeHint().width(), d->mActualSizeButton->sizeHint().width());
     d->mZoomToFitButton->setFixedWidth(width);
     d->mActualSizeButton->setFixedWidth(width);
+    d->mZoomToFitWidthButton->setFixedWidth(width);
 }
 
 void ZoomWidget::slotZoomSliderActionTriggered()
@@ -190,24 +198,4 @@ void ZoomWidget::setMaximumZoom(qreal zoom)
     d->mZoomSlider->setMaximum(sliderValueForZoom(zoom));
 }
 
-bool ZoomWidget::isZoomLocked() const
-{
-    return d->mLockZoomButton->isVisible() && d->mLockZoomButton->isChecked();
-}
-
-void ZoomWidget::setZoomLocked(bool locked)
-{
-    d->mLockZoomButton->setChecked(locked);
-}
-
-void ZoomWidget::setLockZoomButtonVisible(bool visible)
-{
-    d->mLockZoomButton->setVisible(visible);
-}
-
-void ZoomWidget::updateLockZoomButton()
-{
-    d->mLockZoomButton->setIcon(KIcon(d->mLockZoomButton->isChecked() ? "object-locked" : "object-unlocked"));
-}
-
 } // namespace
